==> apache-wicket-6.30.0.zip: apache-wicket-6.30.0/wicket-core/src/test/java/org/apache/wicket/markup/resolver/issue3559/MyTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.markup.resolver.issue3559;

import org.apache.wicket.Page;
import org.apache.wicket.WicketTestCase;
import org.junit.Test;

/**
 * issue-3559
 */
public class MyTest extends WicketTestCase
{
	/**
	 * 
	 */
	@Test
	public void test1()
	{
		tester.startPage(HomePage.class);
		Page page = tester.getLastRenderedPage();
		assertNotNull(page);
		String doc = tester.getLastResponseAsString();
		assertNotNull(doc);

		tester.startPage(SimplePage.class);
		page = tester.getLastRenderedPage();
		assertNotNull(page);
		doc = tester.getLastResponseAsString();
		assertNotNull(doc);

		tester.startPage(HomePage.class);
		page = tester.getLastRenderedPage();
		assertNotNull(page);
		doc = tester.getLastResponseAsString();
		assertNotNull(doc);
	}
}

==> apache-wicket-8.17.0.zip: apache-wicket-8.17.0/wicket-core/src/test/java/org/apache/wicket/markup/resolver/issue3559/MyTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.markup.resolver.issue3559;

import org.apache.wicket.Page;
import org.apache.wicket.util.tester.WicketTestCase;
import org.junit.Test;

/**
 * issue-3559
 */
public class MyTest extends WicketTestCase
{
	/**
	 * 
	 */
	@Test
	public void test1()
	{
		tester.startPage(HomePage.class);
		Page page = tester.getLastRenderedPage();
		assertNotNull(page);
		String doc = tester.getLastResponseAsString();
		assertNotNull(doc);

		tester.startPage(SimplePage.class);
		page = tester.getLastRenderedPage();
		assertNotNull(page);
		doc = tester.getLastResponseAsString();
		assertNotNull(doc);

		tester.startPage(HomePage.class);
		page = tester.getLastRenderedPage();
		assertNotNull(page);
		doc = tester.getLastResponseAsString();
		assertNotNull(doc);
	}
}
